@@ -4,7 +4,7 @@ use warnings;
 
 package Dist::Zilla::PluginBundle::DOHERTY;
 BEGIN {
-  $Dist::Zilla::PluginBundle::DOHERTY::VERSION = '0.008';
+  $Dist::Zilla::PluginBundle::DOHERTY::VERSION = '0.009';
 }
 # ABSTRACT: configure Dist::Zilla like DOHERTY
 
@@ -35,7 +35,8 @@ use Dist::Zilla::PluginBundle::TestingMania             qw();
 use Dist::Zilla::Plugin::InstallRelease           0.002 qw();
 use Dist::Zilla::Plugin::CheckExtraTests                qw();
 use Dist::Zilla::Plugin::GithubUpdate              0.03 qw(); # Support for p3rl.org
-use Dist::Zilla::Plugin::Twitter                  0.009 qw();
+use Dist::Zilla::Plugin::Twitter                  0.010 qw(); # Support for choosing WWW::Shorten::$site via WWW::Shorten::Simple
+use WWW::Shorten::IsGd                                  qw(); # Shorten with WWW::Shorten::IsGd
 
 use Pod::Weaver::Section::BugsAndLimitations   1.102670 qw(); # to read from D::Z::P::Bugtracker
 use Pod::Weaver::PluginBundle::DOHERTY            0.002 qw();
@@ -152,21 +153,20 @@ sub configure {
         'InstallRelease',
         [ 'NextRelease' => { filename => 'CHANGES', format => '%-9v %{yyyy-MM-dd}d' } ],
     );
-    $self->add_plugins(
-        [ 'Twitter' => { hash_tags => '#perl #cpan' } ],
-    ) if $self->twitter;
+    $self->add_plugins([ 'Twitter' => { hash_tags => '#perl #cpan', url_shortener => 'IsGd' } ])
+        if ($self->twitter and not $self->fake_release);
 
     $self->add_bundle(
         'TestingMania' => {
             add  => $self->payload->{'add_tests'},
             skip => $self->payload->{'skip_tests'},
-        }
+        },
     );
 }
 
 
 __PACKAGE__->meta->make_immutable;
-
+no Moose;
 1;
 
 
@@ -181,7 +181,7 @@ Dist::Zilla::PluginBundle::DOHERTY - configure Dist::Zilla like DOHERTY
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
